MethodChannelSimData class

An implementation of SimDataPlatform that uses method channels.

Inheritance

Constructors

MethodChannelSimData()

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() → Future<String?>
Boiler-plate code
override
getSimData() → Future<String?>
Supported only for Android! Fetches the SIM data and returns List<SimDataModel>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendSMS({required String phoneNumber, required String message, required int subId}) → Future<bool?>
Supported for both android and iOS This requires the SEND_SMS permissions for android. SMS is sent in the background for android and for iOS the plugin uses MFMessageComposeViewController
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited