SimDataModel class

SIM Data Plugin Author: Akshay Doshi

Constructors

SimDataModel({required String carrierName, required bool isESIM, required int subscriptionId, required int simSlotIndex, required int cardId, required String phoneNumber, required String displayName, required String countryCode})
Constructor
SimDataModel.fromJson(Map<String, dynamic> json)
Parses the json data into SimDataModel
factory

Properties

cardId → int
Card Id of the SIM card
final
carrierName → String
SIM card carrier name
final
countryCode → String
Country code associated with the SIM card
final
displayName → String
Display name of the SIM card
final
hashCode → int
The hash code for this object.
no setterinherited
isESIM → bool
if the detected SIM card is an eSIM
final
phoneNumber → String
Phone number associated with the SIM card
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
simSlotIndex → int
Sim slot index of the SIM card. 0 of 1st slot and 1 for 2nd slot
final
subscriptionId → int
Subscription ID of the SIM card
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
returns the sim data models as a Map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited